@@ -4,6 +4,8 @@
 from pkg_resources import get_distribution
 __version__ = get_distribution("iamtokenizing").version
 
-from .tokentokens.tokentokens import Token, Tokens
+from .ngrams import NGrams
+from .chargrams import CharGrams
+from .regex_detector import RegexDetector
 
 
